@@ -28,7 +28,6 @@
 #include "libkwave/PluginSetupDialog.h"
 #include "ui_BandPassDlg.h"
 
-class QStringList;
 class QWidget;
 
 namespace Kwave
@@ -53,16 +52,16 @@ namespace Kwave
         BandPassDialog(QWidget *parent, double sample_rate);
 
         /** Destructor */
-        virtual ~BandPassDialog() Q_DECL_OVERRIDE;
+        ~BandPassDialog() override;
 
         /** Returns the parameters as string list */
-        virtual QStringList params() Q_DECL_OVERRIDE;
+        QStringList params() override;
 
         /** Sets the from a list of parameters */
-        virtual void setParams(QStringList &params) Q_DECL_OVERRIDE;
+        void setParams(QStringList &params) override;
 
         /** retruns a pointer to this as a QDialog */
-        virtual QDialog *dialog() Q_DECL_OVERRIDE { return this; }
+        QDialog *dialog() override { return this; }
 
     signals:
 
