@@ -77,7 +77,7 @@ Kwave::PluginSetupDialog *Kwave::BandPassPlugin::createDialog(QWidget *parent)
     Kwave::BandPassDialog *dialog =
         new(std::nothrow) Kwave::BandPassDialog(parent, signalRate());
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     // connect the signals for detecting value changes in pre-listen mode
     connect(dialog, SIGNAL(freqChanged(double)),
@@ -143,3 +143,5 @@ void Kwave::BandPassPlugin::setBwValue(double bw)
 #include "BandPassPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_BandPassPlugin.cpp"
