@@ -37,10 +37,10 @@ namespace Kwave
         AudiofileDecoder();
 
         /** Destructor */
-        virtual ~AudiofileDecoder() Q_DECL_OVERRIDE;
+        ~AudiofileDecoder() override;
 
         /** Returns a new instance of the decoder */
-        virtual Kwave::Decoder *instance() Q_DECL_OVERRIDE;
+        Kwave::Decoder *instance() override;
 
         /**
          * Opens the source and decodes the header information.
@@ -49,7 +49,7 @@ namespace Kwave
          * @param source file or other source with a stream of bytes
          * @return true if succeeded, false on errors
          */
-        virtual bool open(QWidget *widget, QIODevice &source) Q_DECL_OVERRIDE;
+        bool open(QWidget *widget, QIODevice &source) override;
 
         /**
          * Decodes a stream of bytes into a MultiWriter
@@ -59,12 +59,12 @@ namespace Kwave
          * @return true if succeeded, false on errors
          */
         virtual bool decode(QWidget *widget, Kwave::MultiWriter &dst)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Closes the source.
          */
-        virtual void close() Q_DECL_OVERRIDE;
+        void close() override;
 
     private:
 
