@@ -54,7 +54,7 @@ namespace Kwave
         OpusEncoder();
 
         /** Destructor */
-        virtual ~OpusEncoder() Q_DECL_OVERRIDE;
+        ~OpusEncoder() override;
 
         /**
          * parse the header of the stream and initialize the decoder
@@ -65,14 +65,14 @@ namespace Kwave
          */
         virtual bool open(QWidget *widget,
                           const Kwave::FileInfo &info,
-                          Kwave::MultiTrackReader &src) Q_DECL_OVERRIDE;
+                          Kwave::MultiTrackReader &src) override;
 
         /**
          * write the header information
          * @param dst a QIODevice that receives the raw data
          * @return true if succeeded, false if failed
          */
-        virtual bool writeHeader(QIODevice &dst) Q_DECL_OVERRIDE;
+        bool writeHeader(QIODevice &dst) override;
 
         /**
          * encode received ogg data
@@ -81,12 +81,12 @@ namespace Kwave
          * @return true if succeeded, false if failed
          */
         virtual bool encode(Kwave::MultiTrackReader &src,
-                            QIODevice &dst) Q_DECL_OVERRIDE;
+                            QIODevice &dst) override;
 
         /**
          * finished the encoding, clean up
          */
-        virtual void close() Q_DECL_OVERRIDE;
+        void close() override;
 
     private:
 
